@@ -2,7 +2,7 @@
 # Copyright 2015 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Customise edit dialogue to edit or insert chess engine definition record.
+"""Customise edit toplevel to edit or insert chess engine definition record.
 """
 from urllib.parse import urlsplit, parse_qs
 import tkinter.messagebox
@@ -11,51 +11,83 @@ from solentware_grid.gui.dataedit import DataEdit
 
 from solentware_misc.gui.exceptionhandler import ExceptionHandler
 
-from .enginedisplay import DialogueEngineDisplay, DialogueEngineEdit
+from .enginetoplevel import EngineToplevel, EngineToplevelEdit
+from .topleveltext import EditText
 
 
-class ChessDBeditEngine(ExceptionHandler, DataEdit):
-    """Dialog to edit or insert a chess engine definition on database.
+class EngineDbEdit(ExceptionHandler, EditText, DataEdit):
+    """Edit chess engine definition on database, or insert a new record.
 
-    The chess engine definition is in it's own Toplevel widget.
+    parent is used as the master argument in EngineToplevelEdit calls.
+
+    ui is used as the ui argument in EngineToplevelEdit calls.
+
+    newobject, parent, oldobject, and the one or two EngineToplevelEdit
+    instances created, are used as arguments in the super.__init__ call.
+
+    showinitial determines whether a EngineToplevelEdit is created for
+    oldobject if there is one.
+
+    Attribute text_name provides the name used in widget titles and message
+    text.
+
+    Methods get_title_for_object and set_item, and properties ui_base_table;
+    ui_items_in_toplevels; and ui, allow similar methods in various classes
+    to be expressed identically and defined once.
 
     """
+    text_name = 'Engine Definition'
 
     def __init__(self, newobject, parent, oldobject, showinitial=True, ui=None):
-        """Create dialogue to edit or insert chess engine definition."""
-        if oldobject:
-            title = ':  '.join((
-                'Edit Engine Definition',
-                oldobject.value._description_string))
-        else:
-            title = 'Insert Engine Definition'
+        """Extend and create toplevel to edit or insert chess engine definition.
+
+        ui should be a UCI instance.
+
+        """
+        if not oldobject:
             showinitial = False
-        self.__title = title.split(':')[0]
-        if showinitial:
-            showinitial = DialogueEngineDisplay(master=parent, ui=ui)
-            if ui is not None:
-                ui.engines_in_toplevels.add(showinitial)
-            showinitial.definition.extract_engine_definition(
-                oldobject.get_srvalue())
-            showinitial.set_engine_definition()
-        newview = DialogueEngineEdit(master=parent, ui=ui)
-        if ui is not None:
-            ui.engines_in_toplevels.add(newview)
-        newview.definition.extract_engine_definition(newobject.get_srvalue())
-        newview.set_engine_definition()
-        super(ChessDBeditEngine, self).__init__(
+        super().__init__(
             newobject,
             parent,
             oldobject,
-            newview,
-            title,
-            oldview=showinitial,
+            EngineToplevelEdit(master=parent, ui=ui),
+            '',
+            oldview=EngineToplevel(master=parent,
+                                   ui=ui) if showinitial else showinitial,
             )
+        self.initialize()
 
-        # Bind only to newview.score because it alone takes focus.
-        self.bind_buttons_to_widget(newview.score)
+    def get_title_for_object(self, object_=None):
+        """Return title for Toplevel containing a chess engine definition
+        object_.
 
-        self.ui = ui
+        Default value of object_ is oldobject attribute from DataEdit class.
+
+        """
+        if object_ is None:
+            object_ = self.oldobject
+        if object_:
+            return '  '.join((
+                self.text_name.join(('Edit ', ':')),
+                object_.value.get_name_text()))
+        else:
+            return ''.join(('Insert ', self.text_name))
+
+    @property
+    def ui_base_table(self):
+        return self.ui.base_engines
+
+    @property
+    def ui_items_in_toplevels(self):
+        return self.ui.engines_in_toplevels
+
+    @property
+    def ui(self):
+        return self.newview.ui
+
+    def set_item(self, view, object_):
+        view.definition.extract_engine_definition(object_.get_srvalue())
+        view.set_engine_definition(object_.value)
         
     def dialog_ok(self):
         """Update record and return update action response (True for updated).
@@ -64,19 +96,12 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
         started.
 
         """
-        if self.ui.database is None:
-            self.status.configure(
-                text='Cannot update because not connected to a database')
-            if self.ok:
-                self.ok.destroy()
-                self.ok = None
-            self.blockchange = True
-            return False
         ed = self.newview.get_name_engine_definition_dict()
+        title = self.get_title_for_object(),
         if not ed:
             tkinter.messagebox.showerror(
                 parent = self.parent,
-                title=self.__title,
+                title=title,
                 message=''.join(('No chess engine definition given.\n\n',
                                  'Name of chess engine definition must be ',
                                  'first line, and subsequent lines the ',
@@ -87,7 +112,7 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
         if not self.newobject.value.get_engine_command_text():
             tkinter.messagebox.showerror(
                 parent = self.parent,
-                title=self.__title,
+                title=title,
                 message=''.join(('No chess engine definition given.\n\n',
                                  'Name of chess engine definition must be ',
                                  'first line, and subsequent lines the ',
@@ -100,7 +125,7 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
         except ValueError as exc:
             tkinter.messagebox.showerror(
                 parent = self.parent,
-                title=self.__title,
+                title=title,
                 message=''.join(('Invalid chess engine definition given.\n\n',
                                  'The reported error for the port is:\n\n',
                                  str(exc),
@@ -110,7 +135,7 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
             if url.path and url.query:
                 tkinter.messagebox.showerror(
                     parent = self.parent,
-                    title=self.__title,
+                    title=title,
                     message=''.join(
                         ('Give engine as query with hostname or port.\n\n',
                          "Path is: '", url.path, "'.\n\n",
@@ -120,7 +145,7 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
             elif url.path:
                 tkinter.messagebox.showerror(
                     parent = self.parent,
-                    title=self.__title,
+                    title=title,
                     message=''.join(
                         ('Give engine as query with hostname or port.\n\n',
                          "Path is: '", url.path, "'.\n",
@@ -129,7 +154,7 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
             elif not url.query:
                 tkinter.messagebox.showerror(
                     parent = self.parent,
-                    title=self.__title,
+                    title=title,
                     message='Give engine as query with hostname or port.\n\n')
                 return False
             else:
@@ -138,7 +163,7 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
                 except ValueError as exc:
                     tkinter.messagebox.showerror(
                         parent = self.parent,
-                        title=self.__title,
+                        title=title,
                         message=''.join(
                             ("Problem specifying chess engine.  The reported ",
                              "error is:\n\n'",
@@ -148,7 +173,7 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
                 if len(query) > 1:
                     tkinter.messagebox.showerror(
                         parent = self.parent,
-                        title=self.__title,
+                        title=title,
                         message=''.join(
                             ("Give engine as single 'key=value' or ",
                              "'value'.\n\n",
@@ -160,7 +185,7 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
                         if k != 'name':
                             tkinter.messagebox.showerror(
                                 parent = self.parent,
-                                title=self.__title,
+                                title=title,
                                 message=''.join(
                                     ("Give engine as single 'key=value' or ",
                                      "'value'.\n\n",
@@ -171,7 +196,7 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
                         elif len(v) > 1:
                             tkinter.messagebox.showerror(
                                 parent = self.parent,
-                                title=self.__title,
+                                title=title,
                                 message=''.join(
                                     ("Give engine as single 'key=value' or ",
                                      "'value'.\n\n",
@@ -182,7 +207,7 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
         elif url.path and url.query:
             tkinter.messagebox.showerror(
                 parent = self.parent,
-                title=self.__title,
+                title=title,
                 message=''.join(
                     ('Give engine as path without hostname or port.\n\n',
                      "Path is: '", url.path, "'.\n\n",
@@ -192,7 +217,7 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
         elif url.query:
             tkinter.messagebox.showerror(
                 parent = self.parent,
-                title=self.__title,
+                title=title,
                 message=''.join(
                     ('Give engine as path without hostname or port.\n\n',
                      "Query is: '", url.query, "'.\n",
@@ -201,19 +226,16 @@ class ChessDBeditEngine(ExceptionHandler, DataEdit):
         elif not url.path:
             tkinter.messagebox.showerror(
                 parent = self.parent,
-                title=self.__title,
+                title=title,
                 message='Give engine as path without hostname or port.\n')
             return False
-        return super(ChessDBeditEngine, self).dialog_ok()
+        return super().dialog_ok()
 
     def tidy_on_destroy(self):
-        """Clear up after dialogue destruction."""
-        self.ui.engines_in_toplevels.discard(self.oldview)
-        self.ui.engines_in_toplevels.discard(self.newview)
-
-        # base_engines is None when this happens on Quit.
+        # ui_base_table is None when this happens other than directly closing
+        # the Toplevel.
         try:
-            self.ui.base_engines.selection.clear()
+            super().tidy_on_destroy()
         except AttributeError:
-            if self.ui.base_engines is not None:
+            if self.ui_base_table is not None:
                 raise
