@@ -2,28 +2,42 @@
 # Copyright 2016 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Display a chess engine definition.
+"""Widget to display a chess engine definition.
 """
 
 import tkinter
 import tkinter.messagebox
 from urllib.parse import urlsplit
 
-from solentware_misc.gui.exceptionhandler import ExceptionHandler
-
 from ..core.engine import Engine
 from .eventspec import EventSpec
-from .displayitems import DisplayItemsStub
+from .blanktext import NonTagBind, BlankText
+from .sharedtext import SharedTextEngineText
     
 
-class EngineText(ExceptionHandler):
+class EngineText(SharedTextEngineText, BlankText):
 
-    """Chess engine definition widget built from Text and Scrollbar widgets.
+    """Chess engine definition widget.
+
+    panel is used as the panel argument for the super().__init__ call.
+
+    ui is the user interface manager for an instance of EngineText, usually an
+    instance of ChessUI.
+
+    items_manager is used as the items_manager argument for the
+    super().__init__ call.
+
+    itemgrid is the ui reference to the DataGrid from which the record was
+    selected.
+
+    Subclasses are responsible for providing a geometry manager.
+
+    Attribute _most_recent_bindings is set to indicate the initial set of
+    event bindings.  Instances will override this as required.
+
+    
     """
 
-    # True means engine definition can be edited
-    _is_definition_editable = False
-
     def __init__(
         self,
         panel,
@@ -32,61 +46,35 @@ class EngineText(ExceptionHandler):
         itemgrid=None,
         **ka):
         """Create widgets to display chess engine definition."""
-        super(EngineText, self).__init__(**ka)
+        super().__init__(panel, items_manager=items_manager, **ka)
         self.ui = ui
 
-        # May be worth using a Null() instance for these two attributes.
-        if items_manager is None:
-            items_manager = DisplayItemsStub()
-        self.items = items_manager
-
-        self.panel = panel
-        self.score = tkinter.Text(
-            master=self.panel,
-            width=0,
-            height=0,
-            takefocus=tkinter.FALSE,
-            undo=True,
-            wrap=tkinter.WORD)
-        self.scrollbar = tkinter.Scrollbar(
-            master=self.panel,
-            orient=tkinter.VERTICAL,
-            takefocus=tkinter.FALSE,
-            command=self.score.yview)
-        self.score.configure(yscrollcommand=self.scrollbar.set)
-
-        # Keyboard actions do nothing by default.
-        self.disable_keyboard()
-
-        # The popup menus for the engine definition
-
-        self.viewmode_popup = tkinter.Menu(master=self.score, tearoff=False)
-        self.viewmode_navigation_popup = None
+        # The popup menus for the engine definition.
+        self.primary_activity_popup = None
 
         # Selection rule parser instance to process text.
         self.definition = Engine()
         
-    def bind_for_viewmode(self):
-        """Set keyboard bindings for chess engine definition display."""
-        for sequence, function in (
+    # Engine description records are always shown in a Toplevel.
+    # Dismiss item and database update actions by keypress and buttunpress
+    # are assumed to be exposed by the associated solentware_misc class.
+    def get_primary_activity_events(self):
+        return (
             (EventSpec.databaseenginedisplay_run, self.run_engine),
-            ):
-            if function:
-                self.score.bind(sequence[0], self.try_event(function))
-                self.viewmode_popup.add_command(
-                    label=sequence[1],
-                    command=self.try_command(
-                        function, self.viewmode_popup),
-                    accelerator=sequence[2])
+            )
 
-    def bind_pointer_for_viewmode_popup(self):
-        """Show popup menu."""
-        self.score.bind('<ButtonPress-3>',
-                        self.try_event(self.popup_viewmode_menu))
-
-    def give_focus_to_widget(self, event=None):
-        """Do nothing and return 'break'.  Override in subclasses as needed."""
-        return 'break'
+    def set_primary_activity_bindings(self, switch=True):
+        """Switch bindings for editing chess engine definition on or off."""
+        self.set_event_bindings_score(
+            self.get_primary_activity_events(),
+            switch=switch)
+        self.set_event_bindings_score(
+            self.get_F10_popup_events(self.post_active_menu_at_top_left,
+                                      self.post_active_menu),
+            switch=switch)
+        self.set_event_bindings_score(
+            self.get_button_events(buttonpress3=self.post_active_menu),
+            switch=switch)
         
     def set_engine_definition(self, reset_undo=False):
         """Display the chess engine definition as text.
@@ -96,11 +84,13 @@ class EngineText(ExceptionHandler):
         Ctrl-Z in text editing mode recovers the original engine definition.
         
         """
-        if not self._is_definition_editable:
+        if not self._is_text_editable:
             self.score.configure(state=tkinter.NORMAL)
         self.score.delete('1.0', tkinter.END)
         self.map_engine_definition()
-        if not self._is_definition_editable:
+        if self._most_recent_bindings != NonTagBind.NO_EDITABLE_TAGS:
+            self.bind_for_primary_activity()
+        if not self._is_text_editable:
             self.score.configure(state=tkinter.DISABLED)
         if reset_undo:
             self.score.edit_reset()
@@ -127,23 +117,6 @@ class EngineText(ExceptionHandler):
         # No mapping of tokens to text in widget (yet).
         self.score.insert(tkinter.INSERT,
                           self.definition.get_name_engine_command_text())
-        
-    def popup_viewmode_menu(self, event=None):
-        """Show the popup menu for chess engine definition actions.
-
-        Subclasses define particular entries for this menu.  This class adds
-        no items to the menu.
-
-        """
-        if self.items.is_mapped_panel(self.panel):
-            if self is not self.items.active_item:
-                return 'break'
-        self.viewmode_popup.tk_popup(*self.score.winfo_pointerxy())
-
-    def disable_keyboard(self):
-        """"""
-        self.score.bind(EventSpec.selectiontext_disable_keypress[0],
-                        lambda e: 'break')
 
     def run_engine(self, event=None):
         """Run chess engine."""
@@ -175,7 +148,7 @@ class EngineText(ExceptionHandler):
         except ValueError as exc:
             tkinter.messagebox.showerror(
                 parent=self.panel,
-                title=self.__title,
+                title='Run Engine',
                 message=''.join(('The port in the chess engine definition is ',
                                  'invalid.\n\n',
                                  'The reported error for the port is:\n\n',
@@ -212,4 +185,8 @@ class EngineText(ExceptionHandler):
                     'does not name a file.',
                     )))
             return
-        self.ui.run_engine(self.definition.get_engine_command_text())
+        command = self.definition.get_engine_command_text().split(' ', 1)
+        if len(command) == 1:
+            self.ui.run_engine(command[0])
+        else:
+            self.ui.run_engine(command[0], args=command[1].strip())
