@@ -36,8 +36,6 @@ from .constants import (
     TAGS_VARIATIONS_COMMENTS_FONT,
     NAVIGATE_TOKEN,
     NAVIGATE_MOVE,
-    INSERT_RAV,
-    MOVE_EDITED,
     TOKEN,
     RAV_MOVES,
     CHOICE,
@@ -55,7 +53,6 @@ from .constants import (
     START_SCORE_MARK,
     NAVIGATE_COMMENT,
     TOKEN_MARK,
-    INSERT_TOKEN_MARK,
     PGN_TAG,
     ALTERNATIVE_MOVE_COLOR,
     VARIATION_COLOR,
@@ -127,11 +124,6 @@ class PositionScore(ExceptionHandler):
         # black moves after start and end of recursive annotation variation
         # markers.
         self._force_movenumber = False
-        
-    def bind_for_viewmode(self):
-        """Set keyboard bindings for traversing moves."""
-        # Appropriate bindings still to be decided
-        #self.score.bind('<KeyPress>', lambda e: 'break')
 
     # Nothing needed on <Unmap> event at present
     def on_map(self, event):
@@ -155,7 +147,7 @@ class PositionScore(ExceptionHandler):
         # method and _context attributes seems to be able to do the job.
         # Probably including taking account of castling and en-passant options
         # if required.
-        self.rav_number = 0
+        self.variation_number = 0
         self.varstack = []
         self.position_number = 0
         
@@ -168,7 +160,7 @@ class PositionScore(ExceptionHandler):
                     ).read_games(text))
             self._context = context
             try:
-                self.set_game()
+                self.set_and_tag_item_text()
             finally:
                 del self._context
         
@@ -183,11 +175,9 @@ class PositionScore(ExceptionHandler):
         """Destroy the widget displaying game."""
         self.score.destroy()
         
-    def set_game(self, starttoken=None, reset_undo=False):
+    def set_and_tag_item_text(self, reset_undo=False):
         """Display the game as board and moves.
 
-        starttoken is the move played to reach the position displayed and this
-        move becomes the current move.
         reset_undo causes the undo redo stack to be cleared if True.  Set True
         on first display of a game for editing so that repeated Ctrl-Z in text
         editing mode recovers the original score.
@@ -236,16 +226,16 @@ class PositionScore(ExceptionHandler):
                 tag_values.append((t, tags[t]))
         return tag_values
     
-    def get_rav_tag_names(self):
-        """Return suffixed RAV_MOVES and RAV_TAG tag names.
+    def get_variation_tag_names(self):
+        """Return suffixed RAV_MOVES tag names.
 
         The suffixes are arbitrary so increment then generate suffix would be
         just as acceptable but generate then increment uses all numbers
         starting at 0.
 
         """
-        self.rav_number += 1
-        suffix = str(self.rav_number)
+        self.variation_number += 1
+        suffix = str(self.variation_number)
         return ''.join((RAV_MOVES, suffix))
 
     def get_next_positiontag_name(self):
@@ -304,7 +294,7 @@ class PositionScore(ExceptionHandler):
     def is_index_in_main_line(self, index):
         """Return True if index is in the main line tag"""
         return bool(self.score.tag_nextrange(
-            self._gamevartag,
+            self.gamevartag,
             index,
             ''.join((str(index), '+1 chars'))))
 
@@ -353,8 +343,8 @@ class PositionScore(ExceptionHandler):
 
         # With get_current_...() methods as well do not need self._vartag
         # state attributes.
-        self._vartag = self.get_rav_tag_names()
-        self._gamevartag = self._vartag
+        self._vartag = self.get_variation_tag_names()
+        self.gamevartag = self._vartag
 
         self._square_piece_map = {}
         
@@ -388,6 +378,11 @@ class PositionScore(ExceptionHandler):
         else:
             self.score.mark_set(START_SCORE_MARK, '1.0')
 
+        # Delete the attributes used to build the self.score Text widget.
+        del self._square_piece_map
+        del self._force_movenumber
+        del self._vartag
+
     def compare_two_positions(self, one, two):
         """Return True if positions one and two are same, otherwise False.
 
@@ -454,7 +449,7 @@ class PositionScore(ExceptionHandler):
         start, end, sepend = self.insert_token_into_text(token, SPACE_SEP)
         for tag in positiontag, self._vartag, NAVIGATE_MOVE:
             widget.tag_add(tag, start, end)
-        if self._vartag is self._gamevartag:
+        if self._vartag is self.gamevartag:
             widget.tag_add(MOVES_PLAYED_IN_GAME_FONT, start, end)
         widget.tag_add(''.join((RAV_SEP, self._vartag)), start, sepend)
         if not (prev_match_prevcontext or prev_match_currcontext):
@@ -488,7 +483,7 @@ class PositionScore(ExceptionHandler):
         self._set_square_piece_map(position)
         widget = self.score
         self.varstack.append(self._vartag)
-        self._vartag = self.get_rav_tag_names()
+        self._vartag = self.get_variation_tag_names()
         self.insert_token_into_text(token, SPACE_SEP)
         self._force_movenumber = True
 
