@@ -12,7 +12,7 @@ from solentware_grid.datagrid import DataGrid
 from solentware_misc.gui.exceptionhandler import ExceptionHandler
 
 from ..core.chessrecord import ChessDBrecordQuery
-from .querydisplay import DatabaseQueryDisplay, DatabaseQueryEdit
+from .querydisplay import QueryDisplay, QueryDisplayEdit
 from .queryrow import ChessDBrowQuery
 from ..core import exporters
 from .eventspec import EventSpec, DummyEvent
@@ -41,29 +41,32 @@ class QueryListGrid(ExceptionHandler, DataGrid, Display):
         self.hsbar.configure(takefocus=tkinter.FALSE)
         self.vsbar.configure(takefocus=tkinter.FALSE)
         self.ui = ui
-        for sequence, function in (
+        self.set_event_bindings_frame((
             (EventSpec.tab_traverse_forward,
              self.traverse_forward),
             (EventSpec.tab_traverse_backward,
              self.traverse_backward),
             (EventSpec.tab_traverse_round,
              self.traverse_round),
-            ):
-            if function:
-                function = self.try_event(function)
-            self.frame.bind(sequence[0], function)
+
+            # Remove entries when binding implemented in solentware_grid.
+            (EventSpec.score_enable_F10_popupmenu_at_top_left,
+             self.show_grid_or_row_popup_menu_at_top_left_by_keypress),
+            (EventSpec.score_enable_F10_popupmenu_at_pointer,
+             self.show_grid_or_row_popup_menu_at_pointer_by_keypress),
+
+            ))
 
     def display_selected_item(self, key):
-        '''Create DatabaseQueryDisplay for game selection rule.'''
+        '''Create QueryDisplay for game selection rule.'''
         selected = self.get_visible_record(key)
         if selected is None:
             return None
         # Should the Frame containing board and position be created here and
-        # passed to DatabaseQueryDisplay. (Needs 'import Tkinter' above.)
+        # passed to QueryDisplay. (Needs 'import Tkinter' above.)
         # Rather than passing the container where the Frame created by
-        # DatabaseQueryDisplay is to be put.
+        # QueryDisplay is to be put.
         selection = self.make_display_widget(selected)
-        #selection.set_query_statement(reset_undo=True)
         self.ui.add_selection_rule_to_display(selection)
         self.ui.selection_items.increment_object_count(key)
         self.ui.selection_items.set_itemmap(selection, key)
@@ -71,8 +74,8 @@ class QueryListGrid(ExceptionHandler, DataGrid, Display):
         return selection
 
     def make_display_widget(self, sourceobject):
-        """Return a DatabaseQueryDisplay for sourceobject."""
-        selection = DatabaseQueryDisplay(
+        """Return a QueryDisplay for sourceobject."""
+        selection = QueryDisplay(
             master=self.ui.view_selection_rules_pw,
             ui=self.ui,
             items_manager=self.ui.selection_items,
@@ -86,16 +89,15 @@ class QueryListGrid(ExceptionHandler, DataGrid, Display):
         return selection
         
     def edit_selected_item(self, key):
-        '''Create a DatabaseQueryEdit for game selection rule.'''
+        '''Create a QueryDisplayEdit for game selection rule.'''
         selected = self.get_visible_record(key)
         if selected is None:
             return None
         # Should the Frame containing board and position be created here and
-        # passed to DatabaseQueryEdit. (Which needs 'import Tkinter' above.)
+        # passed to QueryDisplayEdit. (Which needs 'import Tkinter' above.)
         # Rather than passing the container where the Frame created by
-        # DatabaseQueryEdit is to be put.
+        # QueryDisplayEdit is to be put.
         selection = self.make_edit_widget(selected)
-        #selection.set_query_statement(reset_undo=True)
         self.ui.add_selection_rule_to_display(selection)
         self.ui.selection_items.increment_object_count(key)
         self.ui.selection_items.set_itemmap(selection, key)
@@ -103,8 +105,8 @@ class QueryListGrid(ExceptionHandler, DataGrid, Display):
         return selection
         
     def make_edit_widget(self, sourceobject):
-        """Return a DatabaseQueryEdit for sourceobject."""
-        selection = DatabaseQueryEdit(
+        """Return a QueryDisplayEdit for sourceobject."""
+        selection = QueryDisplayEdit(
             master=self.ui.view_selection_rules_pw,
             ui=self.ui,
             items_manager=self.ui.selection_items,
@@ -230,7 +232,7 @@ class QueryListGrid(ExceptionHandler, DataGrid, Display):
         
     def create_edit_dialog(
         self, instance, newobject, oldobject, showinitial, modal, title=''):
-        """Extend to do chess initialization"""
+        """Extend to do chess initialization."""
         for x in (newobject, oldobject):
             if x:
                 x.set_database(
@@ -321,29 +323,38 @@ class QueryListGrid(ExceptionHandler, DataGrid, Display):
         if self.get_database() is not None:
             super(QueryListGrid, self).on_data_change(instance)
 
-    def add_navigation_to_popup(self):
-        '''Add 'Navigation' entry to popup menu if not already present.'''
+    def set_popup_bindings(self, popup, bindings=()):
+        for accelerator, function in bindings:
+            popup.add_command(
+                label=accelerator[1],
+                command=self.try_command(function, popup),
+                accelerator=accelerator[2])
 
+    def add_cascade_menu_to_popup(self, index, popup, bindings=None):
+        '''Add cascade_menu, and bindings, to popup if not already present.
+
+        The index is used as the label on the popup menu when visible.
+
+        The bindings are not applied if cascade_menu is alreay in popup menu.
+
+        '''
         # Cannot see a way of asking 'Does entry exist?' other than:
         try:
-            self.menupopup.index('Navigation')
+            popup.index(index)
         except:
-            self.menupopup_navigation = tkinter.Menu(
-                master=self.menupopup, tearoff=False)
-            self.menupopup.add_cascade(
-                label='Navigation', menu=self.menupopup_navigation)
-
-    def add_navigation_to_popup_no_row(self):
-        '''Add 'Navigation' entry to popup menu if not already present.'''
-
-        # Cannot see a way of asking 'Does entry exist?' other than:
-        try:
-            self.menupopupnorow.index('Navigation')
-        except:
-            self.menupopup_navigation_no_row = tkinter.Menu(
-                master=self.menupopupnorow, tearoff=False)
-            self.menupopupnorow.add_cascade(
-                label='Navigation', menu=self.menupopup_navigation_no_row)
+            cascade_menu = tkinter.Menu(master=popup, tearoff=False)
+            popup.add_cascade(label=index, menu=cascade_menu)
+            if bindings is None:
+                return
+            self.set_popup_bindings(cascade_menu, bindings)
+        
+    def set_event_bindings_frame(self, bindings=(), switch=True):
+        """Set bindings if switch is True or unset the bindings."""
+        ste = self.try_event
+        for sequence, function in bindings:
+            self.frame.bind(
+                sequence[0],
+                ste(function) if switch and function else '')
 
     def traverse_backward(self, event=None):
         """Give focus to previous widget type in traversal order."""
@@ -380,11 +391,11 @@ class QueryListGrid(ExceptionHandler, DataGrid, Display):
             return False
         return True
 
-    def export_partial(self, event=None):
-        """Export selected partial position definitions."""
-        exporters.export_grid_positions(
+    def export_selection_rules(self, event=None):
+        """Export selected selection rule definitions."""
+        exporters.export_selected_selection_rules(
             self,
-            self.ui.get_export_filename('Partial Positions', pgn=False))
+            self.ui.get_export_filename('Selection Rules', pgn=False))
 
     def focus_set_frame(self, event=None):
         """Adjust widget which is losing focus then delegate to superclass."""
@@ -402,12 +413,26 @@ class QueryListGrid(ExceptionHandler, DataGrid, Display):
     def get_top_widget(self):
         """Return topmost widget for game display.
 
-        The topmost widget is put in a container widget in some way
+        The topmost widget is put in a container widget in some way.
 
         """
         # Superclass DataGrid.get_frame() method returns the relevant widget.
         # Name, get_top_widget, is compatible with Game and Partial names.
         return self.get_frame()
+
+    def get_visible_selected_key(self):
+        """Return selected key if it is visible and display dialogue if not.
+
+        Getting the key is delegated to superclass.
+
+        """
+        key = super().get_visible_selected_key()
+        if key is None:
+            tkinter.messagebox.showinfo(
+                parent=self.parent,
+                title='Display Item',
+                message='No record selected or selected record is not visible')
+        return key
         
 
 class QueryGrid(QueryListGrid):
@@ -424,68 +449,65 @@ class QueryGrid(QueryListGrid):
         super(QueryGrid, self).__init__(ui.selection_rules_pw, ui)
         self.make_header(ChessDBrowQuery.header_specification)
         self.__bind_on()
-        for function, accelerator in (
-            (self.display_selection_rule_from_popup,
-             EventSpec.display_selection_rule_from_selection_grid),
-            (self.edit_selection_rule_from_popup,
-             EventSpec.edit_selection_rule_from_selection_grid),
-            ):
-            self.menupopup.add_command(
-                label=accelerator[1],
-                command=self.try_command(function, self.menupopup),
-                accelerator=accelerator[2])
-        self.add_navigation_to_popup()
-        self.add_navigation_to_popup_no_row()
-        for function, accelerator in (
-            (self.set_focus_position_grid,
-             EventSpec.selection_grid_to_position_grid),
-            (self.set_focus_gamepanel_item_command,
-             EventSpec.selection_grid_to_active_game),
-            (self.set_focus_game_grid,
-             EventSpec.selection_grid_to_game_grid),
-            (self.set_focus_repertoire_grid,
-             EventSpec.selection_grid_to_repertoire_grid),
-            (self.set_focus_repertoirepanel_item_command,
-             EventSpec.selection_grid_to_active_repertoire),
-            (self.set_focus_repertoire_game_grid,
-             EventSpec.selection_grid_to_repertoire_game_grid),
-            (self.set_focus_partialpanel_item_command,
-             EventSpec.selection_grid_to_active_partial),
-            (self.set_focus_partial_game_grid,
-             EventSpec.selection_grid_to_partial_game_grid),
-            (self.set_focus_partial_grid,
-             EventSpec.selection_grid_to_partial_grid),
-            (self.set_focus_selectionpanel_item_command,
-             EventSpec.selection_grid_to_active_selection_rule),
-            ):
-            for m in (self.menupopup_navigation,
-                      self.menupopup_navigation_no_row):
-                m.add_command(
-                    label=accelerator[1],
-                    command=self.try_command(function, m),
-                    accelerator=accelerator[2])
+        self.set_popup_bindings(self.menupopup, (
+            (EventSpec.display_record_from_grid,
+             self.display_selection_rule_from_popup),
+            (EventSpec.edit_record_from_grid,
+             self.edit_selection_rule_from_popup),
+            ))
+        bindings = (
+            (EventSpec.navigate_to_position_grid,
+             self.set_focus_position_grid),
+            (EventSpec.navigate_to_active_game,
+             self.set_focus_gamepanel_item_command),
+            (EventSpec.navigate_to_game_grid,
+             self.set_focus_game_grid),
+            (EventSpec.navigate_to_repertoire_grid,
+             self.set_focus_repertoire_grid),
+            (EventSpec.navigate_to_active_repertoire,
+             self.set_focus_repertoirepanel_item_command),
+            (EventSpec.navigate_to_repertoire_game_grid,
+             self.set_focus_repertoire_game_grid),
+            (EventSpec.navigate_to_active_partial,
+             self.set_focus_partialpanel_item_command),
+            (EventSpec.navigate_to_partial_game_grid,
+             self.set_focus_partial_game_grid),
+            (EventSpec.navigate_to_partial_grid,
+             self.set_focus_partial_grid),
+            (EventSpec.navigate_to_active_selection_rule,
+             self.set_focus_selectionpanel_item_command),
+            (EventSpec.tab_traverse_backward,
+             self.traverse_backward),
+            (EventSpec.tab_traverse_forward,
+             self.traverse_forward),
+            )
+        self.add_cascade_menu_to_popup(
+            'Navigation',
+            self.menupopup,
+            bindings)
+        self.add_cascade_menu_to_popup(
+            'Navigation',
+            self.menupopupnorow,
+            bindings)
 
     def bind_off(self):
         """Disable all bindings."""
         super(QueryGrid, self).bind_off()
-        for sequence, function in (
-            (EventSpec.selection_grid_to_active_partial, ''),
-            (EventSpec.selection_grid_to_partial_game_grid, ''),
-            (EventSpec.selection_grid_to_repertoire_grid, ''),
-            (EventSpec.selection_grid_to_active_repertoire, ''),
-            (EventSpec.selection_grid_to_repertoire_game_grid, ''),
-            (EventSpec.selection_grid_to_position_grid, ''),
-            (EventSpec.selection_grid_to_active_game,
+        self.set_event_bindings_frame((
+            (EventSpec.navigate_to_active_partial, ''),
+            (EventSpec.navigate_to_partial_game_grid, ''),
+            (EventSpec.navigate_to_repertoire_grid, ''),
+            (EventSpec.navigate_to_active_repertoire, ''),
+            (EventSpec.navigate_to_repertoire_game_grid, ''),
+            (EventSpec.navigate_to_position_grid, ''),
+            (EventSpec.navigate_to_active_game,
              self.set_focus_gamepanel_item),
-            (EventSpec.selection_grid_to_game_grid, ''),
-            (EventSpec.selection_grid_to_partial_grid, ''),
-            (EventSpec.selection_grid_to_active_selection_rule, ''),
-            (EventSpec.display_selection_rule_from_selection_grid, ''),
-            (EventSpec.edit_selection_rule_from_selection_grid, ''),
-            ):
-            if function:
-                function = self.try_event(function)
-            self.frame.bind(sequence[0], function)
+            (EventSpec.navigate_to_game_grid, ''),
+            (EventSpec.navigate_to_partial_grid, ''),
+            (EventSpec.navigate_to_active_selection_rule, ''),
+            (EventSpec.display_record_from_grid, ''),
+            (EventSpec.edit_record_from_grid, ''),
+            ))
 
     def bind_on(self):
         """Enable all bindings."""
@@ -494,42 +516,41 @@ class QueryGrid(QueryListGrid):
 
     def __bind_on(self):
         """Enable all bindings."""
-        for sequence, function in (
-            (EventSpec.selection_grid_to_active_partial,
+        self.set_event_bindings_frame((
+            (EventSpec.navigate_to_active_partial,
              self.set_focus_partialpanel_item),
-            (EventSpec.selection_grid_to_partial_game_grid,
+            (EventSpec.navigate_to_partial_game_grid,
              self.set_focus_partial_game_grid),
-            (EventSpec.selection_grid_to_repertoire_grid,
+            (EventSpec.navigate_to_repertoire_grid,
              self.set_focus_repertoire_grid),
-            (EventSpec.selection_grid_to_active_repertoire,
+            (EventSpec.navigate_to_active_repertoire,
              self.set_focus_repertoirepanel_item),
-            (EventSpec.selection_grid_to_repertoire_game_grid,
+            (EventSpec.navigate_to_repertoire_game_grid,
              self.set_focus_repertoire_game_grid),
-            (EventSpec.selection_grid_to_position_grid,
+            (EventSpec.navigate_to_position_grid,
              self.set_focus_position_grid),
-            (EventSpec.selection_grid_to_active_game,
+            (EventSpec.navigate_to_active_game,
              self.set_focus_gamepanel_item),
-            (EventSpec.selection_grid_to_game_grid,
+            (EventSpec.navigate_to_game_grid,
              self.set_focus_game_grid),
-            (EventSpec.selection_grid_to_partial_grid,
+            (EventSpec.navigate_to_partial_grid,
              self.set_focus_partial_grid),
-            (EventSpec.selection_grid_to_active_selection_rule,
+            (EventSpec.navigate_to_active_selection_rule,
              self.set_focus_selectionpanel_item),
-            (EventSpec.display_selection_rule_from_selection_grid,
+            (EventSpec.display_record_from_grid,
              self.display_selection_rule),
-            (EventSpec.edit_selection_rule_from_selection_grid,
+            (EventSpec.edit_record_from_grid,
              self.edit_selection_rule),
-            ):
-            if function:
-                function = self.try_event(function)
-            self.frame.bind(sequence[0], function)
+            ))
 
     def display_selection_rule(self, event=None):
         """Display selection rule and cancel selection.
 
-        Call _display_selection_rule after idle tasks to allow message display
+        Call _display_selection_rule after idle tasks to allow message display.
 
         """
+        if not self.get_visible_selected_key():
+            return
         self._set_find_selection_rule_name_games(self.selection[0])
         self.frame.after_idle(
             self.try_command(self._display_selection_rule, self.frame))
@@ -537,7 +558,7 @@ class QueryGrid(QueryListGrid):
     def display_selection_rule_from_popup(self, event=None):
         """Display selection rule selected by pointer.
 
-        Call _display_selection_rule after idle tasks to allow message display
+        Call _display_selection_rule after idle tasks to allow message display.
 
         """
         self._set_find_selection_rule_name_games(self.pointer_popup_selection)
@@ -565,9 +586,11 @@ class QueryGrid(QueryListGrid):
     def edit_selection_rule(self, event=None):
         """Display selection rule allow editing and cancel selection.
 
-        Call _edit_selection_rule after idle tasks to allow message display
+        Call _edit_selection_rule after idle tasks to allow message display.
 
         """
+        if not self.get_visible_selected_key():
+            return
         self._set_find_selection_rule_name_games(self.selection[0])
         self.frame.after_idle(
             self.try_command(self._edit_selection_rule, self.frame))
@@ -575,7 +598,7 @@ class QueryGrid(QueryListGrid):
     def edit_selection_rule_from_popup(self, event=None):
         """Display selection rule with editing allowed selected by pointer.
 
-        Call _edit_selection_rule after idle tasks to allow message display
+        Call _edit_selection_rule after idle tasks to allow message display.
 
         """
         self._set_find_selection_rule_name_games(self.pointer_popup_selection)
@@ -635,15 +658,15 @@ class QueryGrid(QueryListGrid):
         return str(self.get_frame()) in self.ui.selection_rules_pw.panes()
 
     def make_display_widget(self, sourceobject):
-        """Return a DatabaseQueryDisplay for sourceobject."""
+        """Return a QueryDisplay for sourceobject."""
         selection = super().make_display_widget(sourceobject)
-        selection.set_query_statement(reset_undo=True)
+        selection.set_and_tag_item_text()
         return selection
         
     def make_edit_widget(self, sourceobject):
-        """Return a DatabaseQueryEdit for sourceobject."""
+        """Return a QueryDisplayEdit for sourceobject."""
         selection = super().make_edit_widget(sourceobject)
-        selection.set_query_statement(reset_undo=True)
+        selection.set_and_tag_item_text(reset_undo=True)
         return selection
 
     def focus_set_frame(self, event=None):
